==> qtjambi-xml-debuginfo-linux-x64-6.6.2.jar: sources/QtJambiXml/QDomDocumentType_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomDocumentType(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomDocumentType")
    QDomDocumentType *_ptr = reinterpret_cast<QDomDocumentType *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomDocumentType()
void __qt_construct_QDomDocumentType(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomDocumentType()")
    Q_UNUSED(__java_arguments)
    QDomDocumentType *__qt_this = new(__qtjambi_ptr) QDomDocumentType();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QDomDocumentType::QDomDocumentType()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_initialize_1native__Lio_qt_xml_QDomDocumentType_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomDocumentType::QDomDocumentType()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomDocumentType, sizeof(QDomDocumentType), typeid(QDomDocumentType), false, &deleter_QDomDocumentType, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDomDocumentType(QDomDocumentType)
void __qt_construct_QDomDocumentType_cref_QDomDocumentType(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomDocumentType(QDomDocumentType)")
    jobject x0 = __java_arguments[0].l;
    const QDomDocumentType& __qt_x0 = qtjambi_cast<const QDomDocumentType& >(__jni_env, x0);
    QDomDocumentType *__qt_this = new(__qtjambi_ptr) QDomDocumentType(__qt_x0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QDomDocumentType::QDomDocumentType(QDomDocumentType)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_initialize_1native__Lio_qt_xml_QDomDocumentType_2Lio_qt_xml_QDomDocumentType_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomDocumentType::QDomDocumentType(QDomDocumentType)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomDocumentType_cref_QDomDocumentType, sizeof(QDomDocumentType), typeid(QDomDocumentType), false, &deleter_QDomDocumentType, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomDocumentType
void __qt_destruct_QDomDocumentType(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomDocumentType")
    reinterpret_cast<QDomDocumentType*>(ptr)->~QDomDocumentType();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomDocumentType::entities()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_entities_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDomDocumentType *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentType>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocumentType::entities()const", __qt_this)
        QDomNamedNodeMap __qt_return_value = __qt_this->entities();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomDocumentType::internalSubset()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_internalSubset_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomDocumentType *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentType>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocumentType::internalSubset()const", __qt_this)
        QString __qt_return_value = __qt_this->internalSubset();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomDocumentType::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomDocumentType *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentType>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocumentType::name()const", __qt_this)
        QString __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomDocumentType::notations()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_notations_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDomDocumentType *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentType>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocumentType::notations()const", __qt_this)
        QDomNamedNodeMap __qt_return_value = __qt_this->notations();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomDocumentType::operator=(QDomDocumentType)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_assign_1native_1cref_1QDomDocumentType__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomDocumentType *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentType>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocumentType::operator=(QDomDocumentType)", __qt_this)
        const QDomDocumentType& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomDocumentType>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomDocumentType::publicId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_publicId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomDocumentType *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentType>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocumentType::publicId()const", __qt_this)
        QString __qt_return_value = __qt_this->publicId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomDocumentType::systemId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_systemId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomDocumentType *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentType>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocumentType::systemId()const", __qt_this)
        QString __qt_return_value = __qt_this->systemId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomDocumentType *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentType>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomDocumentType(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomDocumentType>("QDomDocumentType", "io/qt/xml/QDomDocumentType");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDomDocumentType, {
        ConstructorInfo(&__qt_construct_QDomDocumentType, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomDocumentType_cref_QDomDocumentType, "Lio/qt/xml/QDomDocumentType;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomDocumentType);
    registerMetaType<QDomDocumentType>("QDomDocumentType");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-xml-debuginfo-linux-x64-6.7.1.jar: sources/QtJambiXml/QDomDocumentType_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomDocumentType(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomDocumentType")
    QDomDocumentType *_ptr = reinterpret_cast<QDomDocumentType *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomDocumentType()
void __qt_construct_QDomDocumentType(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomDocumentType()")
    Q_UNUSED(__java_arguments)
    QDomDocumentType *__qt_this = new(__qtjambi_ptr) QDomDocumentType();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QDomDocumentType::QDomDocumentType()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_initialize_1native__Lio_qt_xml_QDomDocumentType_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomDocumentType::QDomDocumentType()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomDocumentType, sizeof(QDomDocumentType), typeid(QDomDocumentType), 0, false, &deleter_QDomDocumentType, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDomDocumentType(QDomDocumentType)
void __qt_construct_QDomDocumentType_cref_QDomDocumentType(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomDocumentType(QDomDocumentType)")
    jobject x0 = __java_arguments[0].l;
    const QDomDocumentType& __qt_x0 = qtjambi_cast<const QDomDocumentType&>(__jni_env, x0);
    QDomDocumentType *__qt_this = new(__qtjambi_ptr) QDomDocumentType(__qt_x0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDomDocumentType::QDomDocumentType(QDomDocumentType)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_initialize_1native__Lio_qt_xml_QDomDocumentType_2Lio_qt_xml_QDomDocumentType_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomDocumentType::QDomDocumentType(QDomDocumentType)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomDocumentType_cref_QDomDocumentType, sizeof(QDomDocumentType), typeid(QDomDocumentType), 0, false, &deleter_QDomDocumentType, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomDocumentType
void __qt_destruct_QDomDocumentType(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomDocumentType")
    reinterpret_cast<QDomDocumentType*>(ptr)->~QDomDocumentType();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomDocumentType::entities()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_entities_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDomDocumentType *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentType>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocumentType::entities()const", __this_nativeId)
        QDomNamedNodeMap __qt_return_value = __qt_this->entities();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomDocumentType::internalSubset()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_internalSubset_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomDocumentType *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentType>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocumentType::internalSubset()const", __this_nativeId)
        QString __qt_return_value = __qt_this->internalSubset();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomDocumentType::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomDocumentType *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentType>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocumentType::name()const", __this_nativeId)
        QString __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomDocumentType::notations()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_notations_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDomDocumentType *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentType>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocumentType::notations()const", __this_nativeId)
        QDomNamedNodeMap __qt_return_value = __qt_this->notations();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomDocumentType::operator=(QDomDocumentType)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_assign_1native_1cref_1QDomDocumentType__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomDocumentType *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentType>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocumentType::operator=(QDomDocumentType)", __this_nativeId)
        const QDomDocumentType& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomDocumentType>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomDocumentType::publicId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_publicId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomDocumentType *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentType>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocumentType::publicId()const", __this_nativeId)
        QString __qt_return_value = __qt_this->publicId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomDocumentType::systemId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_systemId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomDocumentType *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentType>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocumentType::systemId()const", __this_nativeId)
        QString __qt_return_value = __qt_this->systemId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocumentType_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomDocumentType *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocumentType>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomDocumentType(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomDocumentType>("QDomDocumentType", "io/qt/xml/QDomDocumentType");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDomDocumentType, {
        ConstructorInfo(&__qt_construct_QDomDocumentType, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomDocumentType_cref_QDomDocumentType, "Lio/qt/xml/QDomDocumentType;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomDocumentType);
    registerMetaType<QDomDocumentType>("QDomDocumentType");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
